@@ -71,41 +71,6 @@ class PhantomRow(VirtualRow):
         
     def __unicode__(self):
         return unicode(self._ar.get_action_title())
-        
-class EmptyTableRow(VirtualRow):
-    """
-    Base class for virtual rows of an :class:`EmptyTable`.
-    """
-    def __init__(self,table,**kw):
-        self._table = table
-        VirtualRow.__init__(self,**kw)
-        
-    def __unicode__(self):
-        return unicode(self._table.label)
-        
-    def get_print_language(self,pm):
-        return settings.SITE.DEFAULT_LANGUAGE.django_code
-        
-    def get_templates_group(self):
-        return self._table.app_label + '/' + self._table.__name__
-    
-    def filename_root(self):
-        return self._table.app_label + '.' + self._table.__name__
-        
-    def __getattr__(self,name):
-        """
-        Since there is only one EmptyTableRow class, we simulate a 
-        getter here by manually creating an InstanceAction.
-        """
-        v = getattr(self._table,name)
-        if isinstance(v,actions.Action):
-            return actions.InstanceAction(v,self._table,self,None)
-        #~ raise Exception("")
-        raise AttributeError("EmptyTableRow on %s has no action '%s'" % (self._table,name))
-
-
-
-
 
 
 
@@ -117,23 +82,23 @@ class BaseRequest(object):
     A bare BaseRequest instance is returned as a "session" by 
     :meth:`login <lino.ui.Site.login>`.
     """
-    def __init__(self,request=None,renderer=None,**kw):
+    renderer = None
+    
+    #~ def __init__(self,request=None,renderer=None,**kw):
+    def __init__(self,request=None,**kw):
         #~ if ui is None:
             #~ ui = settings.SITE.ui
-        #~ self.ui = ui
-        self.ui = ui = settings.SITE.ui
-        #~ self.error_response = ui.error_response
-        #~ self.success_response = ui.success_response
+        #~ self.ui = ui = settings.SITE.ui
         
         #~ self.prompt = ui.callback
-        self.callback = ui.callback
-        self.confirm = ui.confirm
-        self.error = ui.error
-        self.success = ui.success
-        if renderer is None:
-            #~ renderer = ui.text_renderer
-            renderer = self.ui.default_renderer
-        self.renderer = renderer
+        #~ self.callback = ui.callback
+        #~ self.confirm = ui.confirm
+        #~ self.error = ui.error
+        #~ self.success = ui.success
+        
+        #~ if renderer is None:
+            #~ renderer = ui.default_renderer
+        #~ self.renderer = renderer
         #~ self.step = 0 # confirmation counter
         #~ self.report = actor
         self.request = request
@@ -148,6 +113,11 @@ class BaseRequest(object):
         #~ 20120605 self.ah = actor.get_handle(ui)
         self.setup(**kw)
         
+    def callback(self,*args,**kw): return settings.SITE.ui.callback(*args,**kw)
+    def confirm(self,*args,**kw): return settings.SITE.ui.confirm(*args,**kw)
+    def error(self,*args,**kw): return settings.SITE.ui.error(*args,**kw)
+    def success(self,*args,**kw): return settings.SITE.ui.success(*args,**kw)
+    
     def must_execute(self):
         return True
         
@@ -326,9 +296,20 @@ class BaseRequest(object):
         
     def show(self,spec,column_names=None,**kw):
         ar = self.spawn(spec,**kw)
-        print ar.to_rst(column_names)
+        #~ print ar.to_rst(column_names)
+        return ar.renderer.show(ar,column_names)
         
+    def summary_row(self,obj,**kw):
+        return obj.summary_row(self,**kw)
             
+    def instance_handler(self,*args,**kw): return self.renderer.instance_handler(self,*args,**kw)
+    def href_to(self,*args,**kw): return self.renderer.href_to(self,*args,**kw)
+    def pk2url(self,*args,**kw): return self.renderer.pk2url(self,*args,**kw)
+    def get_request_url(self,*args,**kw): return self.renderer.get_request_url(self,*args,**kw)
+    def obj2html(self,*args,**kw): return self.renderer.obj2html(self,*args,**kw)
+    def href_to_request(self,*args,**kw): return self.renderer.href_to_request(self,*args,**kw)
+    def window_action_button(self,*args,**kw): return self.renderer.window_action_button(self,*args,**kw)
+    def row_action_button(self,obj,a,*args,**kw): return self.renderer.row_action_button(obj,self.request,a,*args,**kw)
 
       
 class ActionRequest(BaseRequest):
@@ -371,13 +352,6 @@ class ActionRequest(BaseRequest):
         self.bound_action = action or actor.default_action
         BaseRequest.__init__(self,request=request,renderer=renderer,**kw)
         self.ah = actor.get_request_handle(self)
-        """
-        See 20120825
-        """
-        #~ if self.actor.parameters is None:
-            #~ if param_values is not None:
-                #~ raise Exception("Cannot request param_values on %s" % self.actor)
-        #~ else:
         if self.actor.parameters is not None:
             pv = self.actor.param_defaults(self)
             
@@ -400,15 +374,15 @@ class ActionRequest(BaseRequest):
                     pv[self.actor.master_key] = self.master_instance
                 
             if param_values is None:
-              if request is not None: # 20121025
-                #~ pv.update(self.ui.parse_params(self.ah,request))
-                #~ pv.update(self.ah.store.parse_params(request))
-                pv.update(self.actor.params_layout.params_store.parse_params(request))
-                
+                if request is not None: # 20121025
+                    #~ pv.update(self.ui.parse_params(self.ah,request))
+                    #~ pv.update(self.ah.store.parse_params(request))
+                    pv.update(self.actor.params_layout.params_store.parse_params(request))
+                    
             if param_values is not None:
                 for k in param_values.keys(): 
                     if not pv.has_key(k):
-                        raise Exception("Invalid key %r in param_values" % k)
+                        raise Exception("Invalid key '%s' in param_values of %s request (possible keys are %s)" % (k,actor,pv.keys()))
                 pv.update(param_values)
                 
             self.param_values = AttrDict(**pv)
@@ -465,7 +439,15 @@ class ActionRequest(BaseRequest):
             #~ if not ca.get_bound_action_permission(self.get_user(),None,None):
                 #~ return
         yield PhantomRow(self,**kw)
-      
+        
+    #~ def get_actor_handle(self):
+        #~ if self._actor_handle is None:
+            #~ self._actor_handle = self.actor.get_request_handle(self)
+        #~ return self._actor_handle
+        #~ 
+    #~ ah = property(get_actor_handle)
+            
+        
     def create_instance(self,**kw):
         if self.create_kw:
             kw.update(self.create_kw)
@@ -509,7 +491,7 @@ class ActionRequest(BaseRequest):
             if ba.action.params_layout.params_store is None:
                 raise Exception("20121016 %s has no store" % ba.action.params_layout)
             kw.update(field_values=ba.action.params_layout.params_store.pv2dict(
-                self.ui,ba.action.action_param_defaults(self,obj)))
+                settings.SITE.ui,ba.action.action_param_defaults(self,obj)))
         return kw
       
       
@@ -536,13 +518,6 @@ class ActionRequest(BaseRequest):
     #~ def prompt(self,*args,**kw): return self.ui.prompt(self,*args,**kw)
     def summary_row(self,*args,**kw): return self.actor.summary_row(self,*args,**kw)
     def get_sum_text(self): return self.actor.get_sum_text(self)
-    def instance_handler(self,*args,**kw): return self.renderer.instance_handler(self,*args,**kw)
-    def href_to(self,*args,**kw): return self.renderer.href_to(self,*args,**kw)
-    def pk2url(self,*args,**kw): return self.renderer.pk2url(self,*args,**kw)
-    def get_request_url(self,*args,**kw): return self.renderer.get_request_url(self,*args,**kw)
-    def obj2html(self,*args,**kw): return self.renderer.obj2html(self,*args,**kw)
-    def href_to_request(self,*args,**kw): return self.renderer.href_to_request(self,*args,**kw)
-    def row_action_button(self,obj,a,*args,**kw): return self.renderer.row_action_button(obj,self.request,a,*args,**kw)
     def as_html(self,*args,**kw): return self.bound_action.action.as_html(self,*args,**kw)
         
     def absolute_uri(self,*args,**kw):
@@ -557,4 +532,3 @@ class ActionRequest(BaseRequest):
         Returns a string representing this request in reStructuredText markup.
         """
         return self.actor.to_rst(self,*args,**kw)
-        #~ raise NotImplementedError()
