@@ -39,7 +39,7 @@ u"""
 ...         return obj[2]
 ...
 
->>> CitiesAndInhabitants.request().render_to_html()
+>>> CitiesAndInhabitants.to_rst()
 
 """
 
@@ -251,6 +251,8 @@ class TableRequest(ActionRequest):
         di = self.data_iterator
         if isinstance(di,QuerySet):
             return di.count()
+        #~ if di is None:
+            #~ raise Exception("data_iterator is None: %s" % self)
         return len(di)
         
 
@@ -260,6 +262,9 @@ class TableRequest(ActionRequest):
     
         
     def parse_req(self,request,rqdata,**kw):
+        """
+        parse the given Django request and setup from it.
+        """
         #~ logger.info("20120723 %s.parse_req()",self.actor)
         #~ rh = self.ah
         master = kw.get('master',self.actor.master)
@@ -351,7 +356,8 @@ class TableRequest(ActionRequest):
         offset = rqdata.get(constants.URL_PARAM_START,None)
         if offset:
             kw.update(offset=int(offset))
-        limit = rqdata.get(constants.URL_PARAM_LIMIT,None)
+        #~ limit = rqdata.get(constants.URL_PARAM_LIMIT,None)
+        limit = rqdata.get(constants.URL_PARAM_LIMIT,15) 
         if limit:
             kw.update(limit=int(limit))
         
@@ -440,7 +446,7 @@ class TableRequest(ActionRequest):
             
     
     def table2xhtml(self):
-        return self.ui.table2xhtml(self)
+        return settings.SITE.ui.table2xhtml(self)
         
     def get_field_info(ar,column_names=None):
         """
@@ -522,7 +528,7 @@ class TableRequest(ActionRequest):
         if not tplfile:
             raise Exception("No file %s / %s" % (tplgroup,tpl_leaf))
             
-        ar.renderer = ar.ui.ext_renderer # 20120624
+        ar.renderer = settings.SITE.ui.ext_renderer # 20120624
         
         context = dict(
             ar=ar,
@@ -606,6 +612,7 @@ class TableHandle(base.Handle):
     def __init__(self,actor):
         self.actor = actor
         base.Handle.__init__(self)
+        #~ super(TableHandle,self).__init__()
   
     def __str__(self):
         #~ return str(self.ui.__class__)+str(self.actor) + 'Handle'
@@ -617,7 +624,7 @@ class TableHandle(base.Handle):
         self._layouts = [ self.list_layout ] 
               
     def get_actor_url(self,*args,**kw):
-        return self.ui.get_actor_url(self.actor,*args,**kw)
+        return settings.SITE.ui.get_actor_url(self.actor,*args,**kw)
         
     def submit_elems(self):
         return []
@@ -632,7 +639,8 @@ class TableHandle(base.Handle):
         return lh.main.columns
         
     def get_slaves(self):
-        return [ sl.get_handle(self.ui) for sl in self.actor._slaves ]
+        #~ return [ sl.get_handle(self.ui) for sl in self.actor._slaves ]
+        return [ sl.get_handle(settings.SITE.ui) for sl in self.actor._slaves ]
             
         
 
@@ -664,6 +672,13 @@ class AbstractTable(actors.Actor):
     """
     _handle_class = TableHandle
     
+    hide_zero_rows = False
+    """
+    Set this to `True` if you want to remove rows which contain no 
+    values when rendering this table as plain HTML.
+    This is ignored when rendered as ExtJS.
+    """
+    
     column_names = '*'
     """
     A string that describes the list of columns of this table.
