@@ -74,6 +74,7 @@ from lino.core import menus
 from lino.utils import jsgen
 from lino.utils.jsgen import py2js, js_code, id2js
 from lino.utils.xmlgen import html as xghtml
+from lino.utils.xmlgen.html import E
 from lino.utils.config import make_dummy_messages_file
 from lino.utils import codetime
 
@@ -125,6 +126,13 @@ class ExtRenderer(HtmlRenderer):
         HtmlRenderer.__init__(self,ui)
         jsgen.register_converter(self.py2js_converter)
         
+        
+    def show(self,ar,*args,**kw):
+        return ar.table2xhtml()
+        #~ return E.tostring(ar.table2xhtml())
+        
+        
+        
     def pk2url(self,ar,pk,**kw):
         return None
         
@@ -256,9 +264,12 @@ class ExtRenderer(HtmlRenderer):
         """
         #~ label = unicode(label or ba.get_button_label())
         label = label or ba.action.label
-        url = 'javascript:Lino.%s(%r,%s)' % (
-                ba.full_name(),str(request.requesting_panel),
-                py2js(obj.pk))
+        if request is None:
+            rp = None
+        else:
+            rp = request.requesting_panel
+        url = 'javascript:Lino.%s(%s,%s)' % (
+                ba.full_name(),py2js(rp),py2js(obj.pk))
         return self.href_button_action(ba,url,label,title or ba.action.help_text,**kw)
         #~ if a.action.help_text:
             #~ return self.href_button(url,label,a.action.help_text)
@@ -647,18 +658,25 @@ tinymce.init({
                 
         
         #~ yield "Lino.load_mask = new Ext.LoadMask(Ext.getBody(), {msg:'Immer mit der Ruhe...'});"
+        
+        dashboard = dict(
+            id="dashboard",
+            xtype='container',
+            autoScroll=True,
+            )
           
         main=dict(
-          id="main_area",
-          xtype='container',
-          region="center",
-          autoScroll=True,
-          layout='fit'
-        )
+            id="main_area",
+            xtype='container',
+            region="center",
+            #~ autoScroll=True,
+            layout='fit',
+            items=dashboard,
+            )
         
         if not on_ready:
             #~ print "20121115 foo"
-            main.update(html=site.get_main_html(request))
+            dashboard.update(html=site.get_main_html(request))
         
         win = dict(
           layout='fit',
