@@ -176,7 +176,7 @@ class CreatePostings(dd.RowAction):
         actions.ShowEmptyTable) # but not from InsertRow
     
     
-    def run(self,elem,ar,**kw):
+    def run_from_ui(self,elem,ar,**kw):
         recs = tuple(elem.get_postable_recipients())
         ar.confirm(
           _("Going to create %(num)d postings for %(elem)s") 
@@ -243,7 +243,7 @@ def setup_explorer_menu(site,ui,profile,m):
     #~ m  = m.add_menu("postings",MODULE_LABEL)
     m.add_action(Postings)
   
-def get_todo_tables(site,ar):
+def get_todo_tables(ar):
     yield (PostingsReady,_("%d postings ready to print"))
                 
   
\ No newline at end of file
