@@ -1,6 +1,6 @@
 SETUP_INFO = dict(name = 'lino',
-  version = '1.6.8',
-  install_requires = ['North==0.1.4','PyYAML','odfpy','jinja2','appy'],
+  version = '1.6.9',
+  install_requires = ['North==0.1.5','djangosite>=0.1.5','PyYAML','odfpy','jinja2','appy'],
   description = "A framework for writing desktop-like web applications using Django and ExtJS",
   license = 'GPL',
   include_package_data = True,
